@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20210129';
+our $VERSION = '0.20210226';
 
-# Table last modified: 2021-01-29
+# Table last modified: 2021-02-26
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -104,7 +104,7 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|1[01357-9]|3[0-69])|2(?:28|51|70|8[2358]|0[137]|3[2-5]|1[4-69]|4[16]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|66|8[06]|5[015]|7[07-9])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|2[0-35-8]|4[2-58]|0[1246-9]|5[24589]|3[0-5])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[1-8]|3[013568]|1[013-7])|6(?:1[0-35-79]|8[28]|6[2578]|3[01346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
+    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[1-8]|3[013568]|1[013-7])|6(?:1[0-35-79]|8[28]|6[2578]|3[01346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|9[0-4]|7[0-25-8]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-579])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|2[0146]|4[05]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|7[03568]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|5[158]|1[014-8]|8[1389]|4[25]|3[0-589]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|3[02358]|4[0-5]|0[1-79])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|4[03489]|0[124-8]|8[168]|2[0-4679]|5[0156]|6[08]|1[05689])|2(?:22|40|1[0-258]|7[17]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
@@ -118,7 +118,7 @@ our %ZIP_TABLE = (
     '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|1[1246]|3[0138]|0[1-35689]|5[015-8]|2[48]|8[035])|7(?:[15]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|6[0-3]|3[38]|5[04-8]|8[16]|1[0-2]|0[1-48])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|7[147]|4[01356]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
-    '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|622))',
+    '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-46]|8[014-8]|4[0134689]|0[1-3578]|3[237])|6[12]1))',
     '120' => '(?:8(?:5(?:44|81|0[17]|7[057]|1[02]|2[068]|3[0469]|5[013-68])|60[12]))',
     '121' => '(?:8(?:5(?:77|1[025]|0[458]|8[58]|5[05]|2[01])|6(?:82|3[39]|1[01])|7(?:11|29)|080))',
@@ -148,14 +148,14 @@ our %ZIP_TABLE = (
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
-    '158' => '(?:8(?:5(?:3[1349]|1[0-58]|8[0568]|5[0-2578]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|1[015]|3[0-3]|2[28]|0[12])|7[07]1))',
+    '158' => '(?:8(?:5(?:3[1349]|1[0-58]|8[0568]|5[0-2578]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
     '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|0[14689]|[24][17]|1[169]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-378])|5(?:65|4[37]|1[0-259]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|(?:68|91)0|8(?:01|12)))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|0[27]|2[12]|8[48]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|26|80|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
     '164' => '(?:8(?:5(?:[37]0|12|67|4[015]|2[25]|8[58]|5[05]|0[13-5])|6(?:[25]0|[37]8|66|8[26]|1[167]|4[24]|0[18])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
-    '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|7[078]|3[1-3589]))',
+    '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
     '168' => '(?:8(?:5(?:[6-8]0|48|5[058]|2[05]|1[0-2]|0[13468]|3[035])|6(?:2[06]|[18][16]|0[18])|081))',
     '169' => '(?:8(?:5(?:8[06]|0[39]|2[0-25-7]|5[0568]|1[6-8]|6[18]|7[078]|4[01]|3[15])|6(?:39|77|0[158]|5[05]|1[0-36]|[46][48])|0(?:50|77|1[12])|7(?:[01]1|22)|(?:88|91)5|228))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
-    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2]|3[689])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|22|65|5[05])|080|173|401))',
+    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2]|3[689])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|22|39|65|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:85(?:[58][058]|1[0-25]|2[0-35-7]|7[27]|6[067]|4[0-2]|0[125-8]|3[039]))',
@@ -323,7 +323,7 @@ our %ZIP_TABLE = (
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-6])|1(?:19[23]|292)))',
-    '350' => '(?:(?:0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|1(?:1(?:8[1-38]|9[24-8])|3(?:8[058]|9[258])|29[25-8])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:92|8[0-278])))',
+    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[058]|9[258])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:92|8[0-278])))',
     '351' => '(?:(?:8(?:5(?:[26]0|55|0[138]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
@@ -382,7 +382,7 @@ our %ZIP_TABLE = (
     '406' => '(?:8(?:5(?:05|10|5[58])|601))',
     '407' => '(?:(?:85(?:11|49|55|0[12])|0192))',
     '408' => '(?:(?:85(?:22|33|85|5[05]|1[15])|01(?:88|92)))',
-    '409' => '(?:(?:3(?:8(?:9[2-8]|8[01357-9])|39[23]|79[23]|293|692)|2(?:19[2-6]|59[2378]|398|992)|1(?:298|392)|019[2358]))',
+    '409' => '(?:(?:3(?:8(?:8[03589]|9[2-8])|39[23]|79[23]|293|692)|2(?:19[2-6]|59[2378]|398|992)|1(?:298|392)|019[2358]))',
     '410' => '(?:(?:8(?:5(?:67|0[148]|2[025]|5[0-258]|8[058]|3[0135]|4[013-5]|7[05]|1[0145])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-8]|39[2-6])|0(?:39[568]|19[25])|3(?:69[36]|292)))',
     '411' => '(?:8(?:5(?:02|33|60|77|88|2[05]|5[15]|[14][01])|6(?:30|89|2[03]|4[148]|6[068]|5[0-2]|1[01])|7(?:[45]0|[78]7|2[025]|3[01])))',
     '412' => '(?:8(?:5(?:24|50|85|1[1-3]|0[15])|6(?:3[04]|0[159])|701))',
@@ -487,7 +487,7 @@ our %ZIP_TABLE = (
     '515' => '(?:(?:8(?:5(?:77|3[03]|2[25]|8[568]|6[67]|1[0135]|5[0578]|0[1359])|688)|2(?:69[23]|592)|059[2568]))',
     '516' => '(?:(?:8(?:5(?:20|77|3[03]|5[0-58]|8[018]|4[3-9]|6[67]|1[12568]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
-    '518' => '(?:(?:0(?:29[2-6]|49[2-6]|192)|85(?:01|18|33)))',
+    '518' => '(?:(?:0(?:29[2-68]|49[2-6]|192)|85(?:01|18|33)))',
     '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
     '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|1[0-356]|7[057]|5[058])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[01])1|0[23]92))',
@@ -528,7 +528,7 @@ our %ZIP_TABLE = (
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[126]|6[01])|6(?:11|0[1245]|5[18])|729))',
-    '560' => '(?:85(?:79|80|5[025]|4[38]|6[0157]|3[12]|0[56]))',
+    '560' => '(?:85(?:79|80|4[38]|5[0-25]|6[0157]|3[12]|0[56]))',
     '561' => '(?:85(?:[06]1|20|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|8[0568]|[05][58]|6[0278])|686))',
     '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
@@ -773,7 +773,7 @@ our %ZIP_TABLE = (
     '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|4[0-68]|2[0-24-689]|7[025-8]|5[0-79]|1[0-8]|6[0-25689])|5(?:[23578]\d|0[1-9]|6[0-689]|[14][0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:77|0[135]|2[025]|6[57]|8[589]|1[0-2]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
-    '815' => '(?:8(?:5(?:11|33|88|4[06]|0[13]|2[09]|5[05])|6(?:[68]6|01)))',
+    '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
     '816' => '(?:8(?:5(?:[67]7|01|30|[58][05]|1[01])|666))',
     '817' => '(?:(?:1(?:[26]92|797)|85(?:20|1[07])))',
     '818' => '(?:(?:8(?:5(?:16|55|67|0[1-3]|7[178]|4[09]|8[58])|6(?:42|86|6[68]))|019[2-578]))',
@@ -916,7 +916,7 @@ our %ZIP_TABLE = (
     '957' => '(?:(?:8(?:5(?:[34]0|11|22|67|5[058]|8[58]|0[236])|6(?:[68]6|01)|701)|0(?:19[235-7]|293)))',
     '958' => '(?:(?:8(?:5(?:01|33|85|5[58])|6(?:01|86))|0292))',
     '959' => '(?:(?:0(?:29[2-6]|59[235-7]|19[2-4]|39[23]|492)|1(?:29[2-468]|39[2357]|69[235]|79[457])|2(?:6(?:88|93)|39[357]|09[23]|292|711)|3(?:19[2-46]|49[23]|292|993)|4(?:49[57]|392)))',
-    '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|1[1-358])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
+    '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|1[1-358])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
     '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[67])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
